==> jc-1.4.0.tar.gz: polyglot/lex/NullLiteral.c <==
// public class polyglot.lex.NullLiteral

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class f280b3524c117768 polyglot_lex_NullLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token
// @dep_class 32c9a088c5dac046 polyglot_util_Position

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header polyglot_lex_NullLiteral
// @dep_header polyglot_util_Position

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "polyglot/lex/NullLiteral.h"
#include "polyglot/util/Position.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(polyglot.util.Position, int)
//

static _jc_linenum _jc_polyglot_lex_NullLiteral$linenum_table$_init$17774dfe64b6222d[];

static const unsigned char _jc_polyglot_lex_NullLiteral$param_ptypes$_init$17774dfe64b6222d[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_INT, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_lex_NullLiteral$param_types$_init$17774dfe64b6222d[] = {
	&_jc_polyglot_util_Position$type,
	&_jc_int$prim$type
};

_jc_method _jc_polyglot_lex_NullLiteral$method_info$_init$17774dfe64b6222d = {
	.name=			"<init>",
	.signature=		"(Lpolyglot/util/Position;I)V",
	.class=			&_jc_polyglot_lex_NullLiteral$type,
	.param_types=		&_jc_polyglot_lex_NullLiteral$param_types$_init$17774dfe64b6222d,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_lex_NullLiteral$param_ptypes$_init$17774dfe64b6222d,
	.signature_hash=	_JC_JLONG(0x17774dfe64b6222d),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_lex_NullLiteral$method$_init$17774dfe64b6222d,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_lex_NullLiteral$linenum_table$_init$17774dfe64b6222d
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_lex_NullLiteral, _init$17774dfe64b6222d);

void
_jc_polyglot_lex_NullLiteral$method$_init$17774dfe64b6222d(_jc_env *const env, _jc_polyglot_lex_NullLiteral$object *this, _jc_polyglot_util_Position$object *param0, jint param1)
{
	jint i0;
	struct _jc_polyglot_lex_NullLiteral$object *r0;
	struct _jc_polyglot_util_Position$object *r1;

	r0 = this;
	r1 = param0;
	i0 = param1;
	_JC_REF_FIELD(env, r0, polyglot_lex_Token, position) = r1;
	_JC_PRIM_FIELD(env, r0, polyglot_lex_Token, symbol) = i0;
	_JC_LINE_NUMBER(8);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_polyglot_lex_NullLiteral$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_polyglot_lex_NullLiteral$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_lex_NullLiteral$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_polyglot_lex_NullLiteral$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_polyglot_lex_NullLiteral$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_lex_NullLiteral$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_lex_NullLiteral$vtable, polyglot_lex_NullLiteral.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_lex_NullLiteral$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_lex_NullLiteral, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_polyglot_lex_NullLiteral$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_polyglot_lex_NullLiteral$object *this)
{
	struct _jc_polyglot_lex_NullLiteral$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(9);				// 0
	return _JC_STRING(env, "NullLiteral <null>");
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_lex_NullLiteral$methods[] = {
	&_jc_polyglot_lex_NullLiteral$method_info$_init$17774dfe64b6222d,
	&_jc_polyglot_lex_NullLiteral$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_96[] = {
	&_jc_polyglot_lex_Token$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_104[] = {
	&_jc_polyglot_lex_NullLiteral$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_119[] = {
	&_jc_polyglot_lex_Literal$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_lex_NullLiteral$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[96]=	_jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_96,
	[104]=	_jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_104,
	[113]=	_jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_113,
	[119]=	_jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_119
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_lex_NullLiteral$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "polyglot/lex/Literal",	_JC_JLONG(0x923d72acc1d3eef7) },
	{ "polyglot/lex/Token",	_JC_JLONG(0x28b2d50426072b60) },
	{ "polyglot/util/Position",	_JC_JLONG(0x32c9a088c5dac046) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_lex_NullLiteral$vtype _jc_polyglot_lex_NullLiteral$type = {
    .type= {
	.name=			"polyglot/lex/NullLiteral",
	.superclass=		&_jc_polyglot_lex_Literal$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0xf280b3524c117768),
		.source_file=		"NullLiteral.java",
		.instance_size=		sizeof(_jc_polyglot_lex_NullLiteral$refs) + sizeof(_jc_polyglot_lex_NullLiteral$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_polyglot_lex_NullLiteral$methods) / sizeof(*_jc_polyglot_lex_NullLiteral$methods),
		.methods=		_jc_polyglot_lex_NullLiteral$methods,
		.instanceof_hash_table=	_jc_polyglot_lex_NullLiteral$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_lex_NullLiteral$class_depends) / sizeof(*_jc_polyglot_lex_NullLiteral$class_depends),
		.class_depends=		_jc_polyglot_lex_NullLiteral$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_polyglot_lex_NullLiteral$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_lex_Token= {
	    .getPosition$93950f582a09a82d=
		&_jc_polyglot_lex_Token$method$getPosition$93950f582a09a82d,
	    .symbol$4d0189d5e9737af4=
		&_jc_polyglot_lex_Token$method$symbol$4d0189d5e9737af4,
	},
	.polyglot_lex_Literal= {
	},
	.polyglot_lex_NullLiteral= {
	    .toString$7ea43b33b80a3070=
		&_jc_polyglot_lex_NullLiteral$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: polyglot/lex/NullLiteral.c <==
// public class polyglot.lex.NullLiteral

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class f280b3524c117768 polyglot_lex_NullLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token
// @dep_class 32c9a088c5dac046 polyglot_util_Position

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header polyglot_lex_NullLiteral
// @dep_header polyglot_util_Position

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "polyglot/lex/NullLiteral.h"
#include "polyglot/util/Position.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(polyglot.util.Position, int)
//

static _jc_linenum _jc_polyglot_lex_NullLiteral$linenum_table$_init$17774dfe64b6222d[];

static const unsigned char _jc_polyglot_lex_NullLiteral$param_ptypes$_init$17774dfe64b6222d[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_INT, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_lex_NullLiteral$param_types$_init$17774dfe64b6222d[] = {
	&_jc_polyglot_util_Position$type,
	&_jc_int$prim$type
};

_jc_method _jc_polyglot_lex_NullLiteral$method_info$_init$17774dfe64b6222d = {
	.name=			"<init>",
	.signature=		"(Lpolyglot/util/Position;I)V",
	.class=			&_jc_polyglot_lex_NullLiteral$type,
	.param_types=		&_jc_polyglot_lex_NullLiteral$param_types$_init$17774dfe64b6222d,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_lex_NullLiteral$param_ptypes$_init$17774dfe64b6222d,
	.signature_hash=	_JC_JLONG(0x17774dfe64b6222d),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_lex_NullLiteral$method$_init$17774dfe64b6222d,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_lex_NullLiteral$linenum_table$_init$17774dfe64b6222d
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_lex_NullLiteral, _init$17774dfe64b6222d);

void _JC_JCNI_ATTR
_jc_polyglot_lex_NullLiteral$method$_init$17774dfe64b6222d(_jc_env *const env, _jc_polyglot_lex_NullLiteral$object *this, _jc_polyglot_util_Position$object *param0, jint param1)
{
	jint i0;
	struct _jc_polyglot_lex_NullLiteral$object *r0;
	struct _jc_polyglot_util_Position$object *r1;

	r0 = this;
	r1 = param0;
	i0 = param1;
	_JC_REF_FIELD(env, r0, polyglot_lex_Token, position) = r1;
	_JC_PRIM_FIELD(env, r0, polyglot_lex_Token, symbol) = i0;
	_JC_LINE_NUMBER(8);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_polyglot_lex_NullLiteral$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_polyglot_lex_NullLiteral$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_lex_NullLiteral$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_polyglot_lex_NullLiteral$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_polyglot_lex_NullLiteral$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_lex_NullLiteral$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_lex_NullLiteral$vtable, polyglot_lex_NullLiteral.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_lex_NullLiteral$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_lex_NullLiteral, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_polyglot_lex_NullLiteral$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_polyglot_lex_NullLiteral$object *this)
{
	struct _jc_polyglot_lex_NullLiteral$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(9);				// 0
	return _JC_STRING(env, "NullLiteral <null>");
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_lex_NullLiteral$methods[] = {
	&_jc_polyglot_lex_NullLiteral$method_info$_init$17774dfe64b6222d,
	&_jc_polyglot_lex_NullLiteral$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_96[] = {
	&_jc_polyglot_lex_Token$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_104[] = {
	&_jc_polyglot_lex_NullLiteral$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_119[] = {
	&_jc_polyglot_lex_Literal$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_lex_NullLiteral$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[96]=	_jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_96,
	[101]=	_jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_101,
	[104]=	_jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_104,
	[119]=	_jc_polyglot_lex_NullLiteral$instanceof_hash_bucket_119
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_lex_NullLiteral$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "polyglot/lex/Literal",	_JC_JLONG(0x923d72acc1d3eef7) },
	{ "polyglot/lex/Token",	_JC_JLONG(0x28b2d50426072b60) },
	{ "polyglot/util/Position",	_JC_JLONG(0x32c9a088c5dac046) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_lex_NullLiteral$vtype _jc_polyglot_lex_NullLiteral$type = {
    .type= {
	.name=			"polyglot/lex/NullLiteral",
	.superclass=		&_jc_polyglot_lex_Literal$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0xf280b3524c117768),
		.source_file=		"NullLiteral.java",
		.instance_size=		sizeof(_jc_polyglot_lex_NullLiteral$refs) + sizeof(_jc_polyglot_lex_NullLiteral$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_polyglot_lex_NullLiteral$methods) / sizeof(*_jc_polyglot_lex_NullLiteral$methods),
		.methods=		_jc_polyglot_lex_NullLiteral$methods,
		.instanceof_hash_table=	_jc_polyglot_lex_NullLiteral$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_lex_NullLiteral$class_depends) / sizeof(*_jc_polyglot_lex_NullLiteral$class_depends),
		.class_depends=		_jc_polyglot_lex_NullLiteral$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_polyglot_lex_NullLiteral$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_lex_Token= {
	    .getPosition$93950f582a09a82d=
		&_jc_polyglot_lex_Token$method$getPosition$93950f582a09a82d,
	    .symbol$4d0189d5e9737af4=
		&_jc_polyglot_lex_Token$method$symbol$4d0189d5e9737af4,
	},
	.polyglot_lex_Literal= {
	},
	.polyglot_lex_NullLiteral= {
	    .toString$7ea43b33b80a3070=
		&_jc_polyglot_lex_NullLiteral$method$toString$7ea43b33b80a3070,
	},
    }
};
